@@ -1,4 +1,35 @@
-import types, operator
+#############################################################################
+##
+## This file is part of PyTango, a python binding for Tango
+##
+## http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
+##
+## (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+## This is free software; you can redistribute it and/or modify
+## it under the terms of the GNU Lesser General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or
+## (at your option) any later version.
+##
+## This software is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU Lesser General Public License for more details.
+##
+## You should have received a copy of the GNU Lesser General Public License
+## along with this program; if not, see <http://www.gnu.org/licenses/>.
+###########################################################################
+
+"""
+This is an internal PyTango module.
+"""
+
+__all__ = []
+
+__docformat__ = "restructuredtext"
+
+import types
+import operator
 
 from _PyTango import StdStringVector
 from _PyTango import Database, DbDatum, DbData
@@ -2006,14 +2037,17 @@ def __doc_DbServerInfo():
         - mode : str
         - level : str"""
 
-def init_db():
+def init(doc=True):
     __init_DbDatum()
-    __doc_DbDatum()
+    if doc:
+        __doc_DbDatum()
+    
     __init_Database()
-    __doc_Database()
-    __doc_DbDevExportInfo()
-    __doc_DbDevImportInfo()
-    __doc_DbDevInfo()
-    __doc_DbHistory()
-    __doc_DbServerInfo()
+    if doc:
+        __doc_Database()
+        __doc_DbDevExportInfo()
+        __doc_DbDevImportInfo()
+        __doc_DbDevInfo()
+        __doc_DbHistory()
+        __doc_DbServerInfo()
 
