@@ -1,4 +1,35 @@
-import operator, types
+#############################################################################
+##
+## This file is part of PyTango, a python binding for Tango
+##
+## http://www.tango-controls.org/static/PyTango/latest/doc/html/index.html
+##
+## (copyleft) CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+## This is free software; you can redistribute it and/or modify
+## it under the terms of the GNU Lesser General Public License as published by
+## the Free Software Foundation; either version 3 of the License, or
+## (at your option) any later version.
+##
+## This software is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU Lesser General Public License for more details.
+##
+## You should have received a copy of the GNU Lesser General Public License
+## along with this program; if not, see <http://www.gnu.org/licenses/>.
+###########################################################################
+
+"""
+This is an internal PyTango module.
+"""
+
+__all__ = []
+            
+__docformat__ = "restructuredtext"
+
+import operator
+import types
 
 from _PyTango import StdStringVector
 from _PyTango import GroupElement
@@ -549,6 +580,7 @@ def __doc_GroupElement():
     # get_parent(self)
     
 
-def init_GroupElement():
+def init(doc=True):
     __init_GroupElement()
-    __doc_GroupElement()
+    if doc:
+        __doc_GroupElement()
